# MUSCIMA

The ``muscima`` (**Mu**sic **Sc**ore **Ima**ges) package implements a data model for the [MUSCIMA++](https://ufal.mff.cuni.cz/muscima)
dataset of music notation.

[![Build Status](https://travis-ci.org/hajicj/muscima.svg?branch=master)](https://travis-ci.org/hajicj/muscima)
[![PyPI version](https://badge.fury.io/py/muscima.svg)](https://badge.fury.io/py/muscima)
[![Documentation Status](https://readthedocs.org/projects/muscima/badge/?version=latest)](https://muscima.readthedocs.io/en/latest/index.html)
[![License: CC BY-NC-SA 4.0](https://img.shields.io/badge/License-MIT-brightgreen.svg)](LICENSE.txt)
[![Coverage Status](https://coveralls.io/repos/github/hajicj/muscima/badge.svg?branch=master)](https://coveralls.io/github/hajicj/muscima?branch=master)
[![codecov](https://codecov.io/gh/hajicj/muscima/branch/master/graph/badge.svg)](https://codecov.io/gh/hajicj/muscima)

This package should work with both Python 2.7 and Python 3.6,
although the doctest-based test suite only works on Python 3.


## Getting started

1. Install this package: ``pip install muscima``
2. Download the [MUSCIMA++ dataset](https://lindat.mff.cuni.cz/repository/xmlui/handle/11372/LRT-2372).
3. Run through the [tutorial](https://muscima.readthedocs.io/en/latest/Tutorial.html#tutorial).



## Dataset
The dataset itself is available for download
[here](https://lindat.mff.cuni.cz/repository/xmlui/handle/11372/LRT-2372) and due to its derived nature, licensed differently:

[![abc](https://img.shields.io/badge/Dataset_Version-1.0-brightgreen.svg)](https://lindat.mff.cuni.cz/repository/xmlui/handle/11372/LRT-2372)
[![License: CC BY-NC-SA 4.0](https://img.shields.io/badge/License-CC%20BY--NC--SA%204.0-blue.svg)](https://creativecommons.org/licenses/by-nc-sa/4.0/)
